@@ -211,6 +211,24 @@
  */
 #undef ISC_PLATFORM_NEEDSTRCASESTR
 
+/***
+ *** System limitations
+ ***/
+
+#include <limits.h>
+
+#ifndef NAME_MAX
+#define NAME_MAX 256
+#endif
+
+#ifndef PATH_MAX
+#define PATH_MAX 1024
+#endif
+
+#ifndef IOV_MAX
+#define IOV_MAX 1024
+#endif
+
 /***
  *** Miscellaneous.
  ***/
